#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var generator_service_1 = require("./services/generator-service");
var di_container_1 = require("./core/di-container");
var commander_1 = require("commander");
var figlet = require("figlet");
var chalk = require("chalk");
commander_1.program.on('--help', function () {
    console.log(chalk.blueBright(figlet.textSync('Mysql 2 TS', { horizontalLayout: 'full' })));
});
commander_1.program
    .version('1.0.0')
    .description('A handy tool to generate typescript models directly from mysql schema')
    .requiredOption('-h, --host <host>', 'database host address [required]')
    .requiredOption('-n, --dbname <dbname>', 'database name [required]')
    .requiredOption('-u, --dbuser <dbuser>', 'database username [required]')
    .requiredOption('-p, --dbpass <dbpass>', 'database password [required]')
    .requiredOption('-r, --dbport <dbport>', 'database port [required]')
    .requiredOption('-o, --output <output>', 'output directory [required]')
    .requiredOption('-m, --mode <mode>', 'output mode [required], options: basic | advanced')
    .option('-c, --namingConvention <string>', 'naming convention for class fields, options: camelCase | pascalCase | snakeCase');
if (process.argv.length === 2) {
    console.log(chalk.blueBright(figlet.textSync('Mysql 2 TS', { horizontalLayout: 'full' })), '\n');
    console.log(commander_1.program.helpInformation());
    process.exit(0);
}
commander_1.program.parse(process.argv);
var conf = {
    DatabaseHost: commander_1.program.host,
    DatabaseName: commander_1.program.dbname,
    DatabasePassword: commander_1.program.dbpass,
    DatabasePort: commander_1.program.dbport,
    DatabaseUsername: commander_1.program.dbuser,
    OutputDirectory: commander_1.program.output,
    Mode: commander_1.program.mode,
    NamingConvention: commander_1.program.namingConvention,
};
var generator = di_container_1.default.resolve(generator_service_1.GeneratorService);
generator.validatorService.validateConfig(conf);
generator.configService.setConfig(conf);
generator.generate();
