"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Table = void 0;
var values_1 = require("./values");
var utils_1 = require("../core/utils");
var Table = /** @class */ (function () {
    function Table(name, columns) {
        this.name = name;
        this.columns = columns;
    }
    Table.prototype.getClassDefinitionString = function (config) {
        this.columns.sort(function (a, b) {
            return a.name.length - b.name.length;
        });
        var output = [];
        if (config.Mode === 'advanced') {
            output.push(this.getImports());
        }
        output.push("export class " + utils_1.upperFirst(this.name) + " {");
        for (var _i = 0, _a = this.columns; _i < _a.length; _i++) {
            var column = _a[_i];
            output.push(column.getFieldDefinition(config));
        }
        output.push('');
        output.push(this.getConstructor(config));
        output.push('');
        if (config.Mode === 'advanced') {
            output.push(this.getCreateMethod());
            output.push(this.getToOriginalMethod(config));
        }
        output.push("}");
        return output.join('\n');
    };
    Table.prototype.getConstructor = function (config, indent) {
        if (indent === void 0) { indent = 1; }
        var output = [];
        output.push(values_1.constructorComments);
        if (config.Mode === 'basic') {
            output.push(' '.repeat(indent * 4) + "constructor(obj: any) {");
        }
        else {
            output.push(' '.repeat(indent * 4) + "private constructor(obj: any) {");
        }
        for (var _i = 0, _a = this.columns; _i < _a.length; _i++) {
            var column = _a[_i];
            output.push(' '.repeat((indent + 1) * 4) + ("this." + utils_1.formatName(config, column.name) + " = obj." + column.name + ";"));
        }
        output.push(' '.repeat(indent * 4) + "}");
        return output.join('\n');
    };
    Table.prototype.getCreateMethod = function (indent) {
        if (indent === void 0) { indent = 1; }
        var output = [];
        output.push(values_1.createMethodComments);
        output.push(' '.repeat(indent * 4) + ("public static Create(obj: any, field: string = 'root'): " + utils_1.upperFirst(this.name) + " {"));
        output.push(values_1.initialCreateValidationString);
        output.push('');
        for (var _i = 0, _a = this.columns; _i < _a.length; _i++) {
            var column = _a[_i];
            output.push(' '.repeat((indent + 1) * 4) + ("check" + utils_1.upperFirst(column.type) + "(obj." + column.name + ", " + column.nullable + ", field + '." + column.name + "');"));
        }
        output.push('');
        output.push(' '.repeat((indent + 1) * 4) + ("return new " + utils_1.upperFirst(this.name) + "(obj);"));
        output.push(' '.repeat(indent * 4) + '}');
        return output.join('\n');
    };
    Table.prototype.getToOriginalMethod = function (config, indent) {
        if (indent === void 0) { indent = 1; }
        var output = [];
        output.push('');
        output.push(values_1.toOriginalMethodComment);
        output.push(' '.repeat(indent * 4) + "public originalObject(json: boolean = false): any {");
        output.push(' '.repeat((indent + 1) * 4) + 'const output: any = {};');
        output.push('');
        for (var _i = 0, _a = this.columns; _i < _a.length; _i++) {
            var col = _a[_i];
            output.push(' '.repeat((indent + 1) * 4) + ("output." + col.name + " = this." + utils_1.formatName(config, col.name) + ";"));
        }
        output.push('');
        output.push(' '.repeat((indent + 1) * 4) + 'if (json) {');
        output.push(' '.repeat((indent + 2) * 4) + 'return JSON.stringify(output);');
        output.push(' '.repeat((indent + 1) * 4) + '} else {');
        output.push(' '.repeat((indent + 2) * 4) + 'return output;');
        output.push(' '.repeat((indent + 1) * 4) + '}');
        output.push(' '.repeat(indent * 4) + "}");
        return output.join('\n');
    };
    Table.prototype.getImports = function () {
        var output = [];
        var imports = ['throwNull2NonNull', 'throwNotObject', 'throwIsArray'];
        for (var _i = 0, _a = this.columns; _i < _a.length; _i++) {
            var column = _a[_i];
            imports.push("check" + utils_1.upperFirst(column.type));
        }
        imports = imports.filter(function (v, i) { return imports.indexOf(v) === i; });
        output.push("import { " + imports.join(', ') + "} from './needed-utils';");
        output.push('');
        return output.join('\n');
    };
    return Table;
}());
exports.Table = Table;
