"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Validator = void 0;
var isValid = require("is-valid-path");
var inversify_1 = require("inversify");
var Validator = /** @class */ (function () {
    function Validator() {
    }
    Validator.prototype.validateConfig = function (config) {
        try {
            this.validateHostname(config.DatabaseHost);
            this.validateDatabaseName(config.DatabaseName);
            this.validatePort(config.DatabasePort);
            this.validateFolderPath(config.OutputDirectory);
            this.validateMode(config.Mode);
            if (config.NamingConvention) {
                this.validateNamingConvention(config.NamingConvention);
            }
        }
        catch (error) {
            console.error(error.message);
            process.exit(1);
        }
    };
    Validator.prototype.validateHostname = function (inputText) {
        var ipFormat = /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
        if (!(inputText.match(ipFormat) || inputText === 'localhost')) {
            throw {
                message: 'validation error: you have entered an invalid hostname',
            };
        }
    };
    Validator.prototype.validateDatabaseName = function (inputText) {
        var nameFormat = /[a-zA-Z]/;
        if (!inputText.match(nameFormat)) {
            throw {
                message: 'validation error: you have entered an invalid database name',
            };
        }
    };
    Validator.prototype.validatePort = function (inputText) {
        var portFormat = /^\d+$/;
        if (!inputText.match(portFormat)) {
            throw {
                message: 'validation error: you have entered an invalid database port',
            };
        }
    };
    Validator.prototype.validateFolderPath = function (inputText) {
        if (!isValid(inputText)) {
            throw {
                message: 'validation error: you have entered an invalid output directory',
            };
        }
    };
    Validator.prototype.validateMode = function (mode) {
        if (mode !== 'basic' && mode !== 'advanced') {
            throw {
                message: 'validation error: you have entered an invalid mode. Use "basic" or "advanced"',
            };
        }
    };
    Validator.prototype.validateNamingConvention = function (namingConvention) {
        if (namingConvention !== 'camelCase' && namingConvention !== 'pascalCase' && namingConvention !== 'snakeCase') {
            throw {
                message: 'validation error: naming convention is invalid. Use "camelCase" or "pascalCase" or "snakeCase"',
            };
        }
    };
    Validator = __decorate([
        inversify_1.injectable()
    ], Validator);
    return Validator;
}());
exports.Validator = Validator;
